@@ -1,4 +1,4 @@
-diag.plot.color <- function(x,plots, subset, color, ...)
+diag.plot.color <- function(x,plots, subset, color, time = NULL, ...)
 {
 	ltBl <- ifelse(color, "lightblue","gray80")
 	rdCol <- ifelse(color, "red","black")
@@ -22,8 +22,15 @@ if (plots == "optimize" || plots == 1) {
 
 	if(is.null(subset))
 	subset <- 1:length(levels(as.factor(optDat$stopRule)))
+	
+	if(is.null(time)){
+		xlb <- "Iteration"
+	}
+	else{
+		xlb <- paste("Iteration (Time ", time, ")", sep = "")
+	}
 
-	pt1 <- xyplot(balance ~ iteration | stopRule, data = optDat, ylab = "Balance measure", xlab = "Iteration", scales = list(alternating = 1), as.table = TRUE, subset = as.factor(optDat$stopRule) %in% levels(as.factor(optDat$stopRule))[subset], col = ptSymCol, par.settings = list(strip.background = list(col=stripBgCol)), ...)
+	pt1 <- xyplot(balance ~ iteration | stopRule, data = optDat, ylab = "Balance measure", xlab = xlb, scales = list(alternating = 1), as.table = TRUE, subset = as.factor(optDat$stopRule) %in% levels(as.factor(optDat$stopRule))[subset], col = ptSymCol, par.settings = list(strip.background = list(col=stripBgCol)), ...)
 	
 }
    
@@ -42,13 +49,20 @@ if (plots == "optimize" || plots == 1) {
    	warning("Some effect sizes are larger than 3 and may not have been plotted.\n")	
    	subsetHold <- !esDat$esBig & (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset])
    	
+	if(is.null(time)){
+		xlb <- NULL
+	}
+	else{
+		xlb <- paste("Time ", time, sep = "")
+	}   	
+   	
    	if(any(subsetHold)){   	
    		esDatTmp <- esDat
    		esDatTmp$effectSize[!subsetHold] <- NA	
    		pt1.1 <- xyplot(effectSize ~ weighted | whichComp, groups = whichVar, data = esDatTmp, scales = list(alternating = 1),
    		ylim = c(-.05, yMax), type = "l", col = ltBl, as.table = TRUE,
    		subset = subsetHold, par.settings = list(strip.background = list(col=stripBgCol)),
-   		ylab = "Absolute standard difference", xlab = NULL, ...,
+   		ylab = "Absolute standard difference", xlab = xlb, ...,
    		panel = function(...){
    			panel.abline(h=c(.2,.5,.8), col="gray80")
    			panel.xyplot(...)
@@ -65,7 +79,7 @@ if (plots == "optimize" || plots == 1) {
    	   	esDatTmp <- esDat
    		esDatTmp$effectSize[!subsetHold] <- NA		
    		pt1.2 <- xyplot(effectSize ~ weighted | whichComp, groups = whichVar, subset = subsetHold, 
-   		data = esDatTmp, ylab = "Absolute standard difference", xlab = NULL, as.table = TRUE, 
+   		data = esDatTmp, ylab = "Absolute standard difference", xlab = xlb, as.table = TRUE, 
    		ylim = c(-.05, yMax), type = "l", col = rdCol, par.settings = list(strip.background = list(col=stripBgCol)),
    		lwd = 2, ...)
    		if(nullPlot){
@@ -84,7 +98,7 @@ if (plots == "optimize" || plots == 1) {
    	else pchHold <- c(19,1)
    	
    	pt2 <- xyplot(effectSize ~ weighted | whichComp, groups = pVal >= .05, data = esDat,
-   		ylab = "Absolute standard difference", xlab = NULL, 
+   		ylab = "Absolute standard difference", xlab = xlb, 
    		ylim = c(-.05, yMax), type = "p", col = rdCol, pch = pchHold,
    		subset = subsetHold, par.settings = list(strip.background = list(col=stripBgCol)), ...)
    	ptHold <- ptHold + pt2
@@ -97,13 +111,21 @@ if (plots == "optimize" || plots == 1) {
    
    if (plots == "t" || plots == 4) { ## t p-values plot
    	
+   	if(is.null(time)){
+		xlb <- "Rank of p-value for pretreatment variables \n (hollow is weighted, solid is unweighted)"
+	}
+	else{
+		xlb <- paste("Rank of p-value for pretreatment variables \n (hollow is weighted, solid is unweighted) \n Time ", time, sep = "")
+	}   	
+   	
+   	
    	esDat <- makePlotDat(x, whichPlot = 4)
    	if(is.null(subset)) subset <- 1:length(levels(as.factor(esDat$whichComp)))
    	
    	
    	
    	n.var2 <- max(esDat$tRank * (!is.na(esDat$tPVal)), na.rm=TRUE)
-   	pt1 <- xyplot(tPVal~tRank|whichComp, groups = weighted, data=esDat, xlab = "Rank of p-value rank for pretreatment variables \n (hollow is weighted, solid is unweighted)", ylab = "T test p-values", pch = c(19,1), col = "black", scales = list(alternating = 1),
+   	pt1 <- xyplot(tPVal~tRank|whichComp, groups = weighted, data=esDat, xlab = xlb, ylab = "T test p-values", pch = c(19,1), col = "black", scales = list(alternating = 1),
    	subset = (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset]) & (esDat$tRank <= n.var2), ylim = c(-.1, 1.1), par.settings = list(strip.background = list(col=stripBgCol)),..., 
    	   	panel = function(...){
    	   		panel.xyplot(x=c(1,n.var2), y=c(0,1), col=ltBl, type="l")
@@ -120,7 +142,14 @@ if (plots == "optimize" || plots == 1) {
    	
    	n.var2 <- max(esDat$ksRank*(!is.na(esDat$ksPVal)), na.rm=TRUE)
    	
-   	pt1 <- xyplot(ksPVal~ksRank|whichComp, groups=weighted, scales = list(alternating = 1), data = esDat,ylim = c(-.1, 1.1), ..., xlab = "Rank of p-value rank for pretreatment variables \n (hollow is weighted, solid is unweighted)", ylab = "KS test p-values", pch = c(19,1), col="black", par.settings = list(strip.background = list(col=stripBgCol)),
+   	if(is.null(time)){
+		xlb <- "Rank of p-value for pretreatment variables \n (hollow is weighted, solid is unweighted)"
+	}
+	else{
+		xlb <- paste("Rank of p-value for pretreatment variables \n (hollow is weighted, solid is unweighted) \n Time ", time, sep = "")
+	}   	   	
+   	
+   	pt1 <- xyplot(ksPVal~ksRank|whichComp, groups=weighted, scales = list(alternating = 1), data = esDat,ylim = c(-.1, 1.1), ..., xlab = xlb, ylab = "KS p-values", pch = c(19,1), col="black", par.settings = list(strip.background = list(col=stripBgCol)),
    	subset = (as.factor(esDat$whichComp) %in% levels(as.factor(esDat$whichComp))[subset]) & (esDat$ksRank <= n.var2),
    	panel = function(...){
    		panel.xyplot(x=c(1,n.var2), y=c(0,1), col= ltBl, type="l")
@@ -132,17 +161,15 @@ if (plots == "optimize" || plots == 1) {
 #   	pt1 <- histogram.dxwts(...)
    	
    	if (plots == "boxplot" || plots == 2){
-#   		bwCols <- list(col = ptSymCol)
-#   		pt1 <- boxplot(x, par.settings = list(strip.background = list(col=stripBgCol), box.rectangle = bwCols, plot.symbol = bwCols, box.umbrella = bwCols),...)
-			pt1 <- boxplot(x, color = color, subset = subset, ...)
+			pt1 <- boxplot(x, color = color, subset = subset, time = time, ...)
    		}
    	
    	if (plots == "histogram" || plots == 6){
    		
-   			treat <- x$treat
-	wghts <- x$w
-	vars <- x$variableNames
-	if (is.null(dots$main)) dots$main <- "Control weights"
+   		treat <- x$treat
+		wghts <- x$w
+		vars <- x$variableNames
+		if (is.null(dots$main)) dots$main <- "Control weights"
 #	if(is.null(x$w.ctrl) || is.null(x$treat))
 #         stop("For the weight histogram w.ctrl and treat cannot be NULL")	
 	if(!all(wghts[,1]==1))   {
@@ -153,14 +180,14 @@ if (plots == "optimize" || plots == 1) {
 	controlWeights <- as.matrix(controlWeights)
 	nFrame <- ncol(controlWeights)
 	longWeights <- matrix(t(controlWeights), ncol=1)
-	longWeights <- data.frame(Weights = longWeights, varb = colnames(controlWeights))
+	longWeights <- data.frame(Weights = longWeights, varb = names(wghts))
 	
 	if(is.null(subset))
-	subset <- 1:length(colnames(controlWeights))
+	subset <- 1:length(unique(longWeights$varb))
 	
 	if(color == FALSE & is.null(dots$col)) 	
-	pt1 <- histogram(~Weights|varb, data=longWeights, par.settings = list(strip.background = list(col=stripBgCol)), subset = varb %in% colnames(controlWeights)[subset], col = NULL, ...)
-	else pt1 <- histogram(~Weights|varb, data=longWeights, par.settings = list(strip.background = list(col=stripBgCol)), subset = varb %in% colnames(controlWeights)[subset], ...) 
+	pt1 <- histogram(~Weights|varb, data=longWeights, par.settings = list(strip.background = list(col=stripBgCol)), subset = varb %in% unique(controlWeights)[subset], col = NULL, ...)
+	else pt1 <- histogram(~Weights|varb, data=longWeights, par.settings = list(strip.background = list(col=stripBgCol)), subset = varb %in% unique(longWeights$varb)[subset], ...) 
 
    		
    		
