@@ -54,7 +54,7 @@ for(i in 1:nMethod){
 	methodList[[i]]$name <- methodName
 	}
 	else {
-		if (class(stop.method[i]) != "stop.method"){
+		if (class(stop.method[i])[1] != "stop.method"){
 			print(allowableStopMethods)
 			stop("Each element of stop.method must either be one of \nthe above character strings, or an object of the stop.method class.")	
 		}
